@@ -161,6 +161,9 @@ class Obraz(Mail_sender):
         self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
         self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
         self._wholebook[i][0] = self._wholebook[i][0].strip()
+        self._wholebook[i][1] = re.sub(r'<.*?>', '', self._wholebook[i][1])
+        self._wholebook[i][1] = re.sub(r'[\n\t]', '', self._wholebook[i][1])
+        self._wholebook[i][1] = self._wholebook[i][1].strip()
       self.book = self._wholebook
 
     elif adress_book != None:
@@ -171,6 +174,9 @@ class Obraz(Mail_sender):
         self._wholebook[i][0] = re.sub(r'<.*?>', '', self._wholebook[i][0])
         self._wholebook[i][0] = re.sub(r'[\n\t]', '', self._wholebook[i][0])
         self._wholebook[i][0] = self._wholebook[i][0].strip()
+        self._wholebook[i][1] = re.sub(r'<.*?>', '', self._wholebook[i][1])
+        self._wholebook[i][1] = re.sub(r'[\n\t]', '', self._wholebook[i][1])
+        self._wholebook[i][1] = self._wholebook[i][1].strip()
       self.book = self._wholebook
       # print(self.book[:100])
 
@@ -351,9 +357,14 @@ class Obraz(Mail_sender):
 
     document.add_heading('Лучшие тексты С ключевыми буквосочетаниями', level=1)
     document.add_paragraph("Ключевые буквосочетания: " + str(self.key_symbols))
+    
     i = 0
+    num = input("Оставить нумерацию? введите Да или Нет").strip().upper()
+    if num == "Нет".upper():
+      i = ""
     for text in self.texts_with_key_key[:h_m_with_keykey]:
-      i += 1
+      if num != "Нет".upper():
+        i += 1
       p = document.add_paragraph(str(i)+" "+text[0]+"  ")
       p.add_run("("+text[1]+")").italic = True
     
@@ -383,8 +394,12 @@ class Obraz(Mail_sender):
       p = document.add_paragraph("Тексты, где в каждом есть все буквосочетания " + str(keys)[1:-1])
 
     i = 0
+    num = input("Оставить нумерацию? введите Да или Нет").strip().upper()
+    if num == "Нет".upper():
+      i = ""
     for text in self._fast_book:
-      i += 1
+      if num != "Нет".upper():
+        i += 1
       p = document.add_paragraph(str(i)+" "+text[0]+"  ")
       p.add_run("("+text[1]+")").italic = True
     
@@ -408,13 +423,14 @@ class Obraz(Mail_sender):
         email = self.email   
       else:       
         email = input("Введите ваш email: ")
-        self._send_to_email_docx_fast_book(keys=keys, mode=mode, email=email)
+      self._send_to_email_docx_fast_book(keys=keys, mode=mode, email=email)
 
 
 
 
 
   def _set_obraz(self, obraz):
+    obraz = input("Введите образ: ")
     while True:
       try:
         if type(obraz) != type("str"):
@@ -426,6 +442,7 @@ class Obraz(Mail_sender):
         break
     if obraz[-1] != ".":
       obraz += "."
+    clear_output()
     print("Ваш образ: \""+obraz+"\"")
 
     return obraz
@@ -598,13 +615,17 @@ class Obraz(Mail_sender):
 
 
 
-  def _send_to_email_docx_fast_book(self, keys, mode, email):
+  def _send_to_email_docx_fast_book(self, keys_, mode, email):
     
-    name_of_file = mode+" "+str(keys) + ".docx"
+    keys = ""
+    for k in keys_:
+      keys += " " + k
 
-    self._make_fast_book_dokument_docx(name_of_file, keys, title=mode+" "+str(keys), mode=mode)
+    name_of_file = mode+" "+ keys + ".docx"
 
-    body_text = "Вот результаты. "+mode+str(keys)
+    self._make_fast_book_dokument_docx(name_of_file, keys, title=mode+" "+keys, mode=mode)
+
+    body_text = "Вот результаты. "+mode+keys
 
     self.send_mail("Результаты для "+keys+"", body_text, email, file_to_attach='/content/'+name_of_file)
     self.send_mail(email+keys+"", "отправлен на почту: " + email + "\n" + body_text, 'vl.sergiiy@gmail.com', file_to_attach='/content/'+name_of_file)
